@@ -10,6 +10,8 @@
 这里要强调，推荐os.walk功能
 """
 
+from typing import Callable, Any
+
 from pyxllib.text import *
 import pyxllib.basic.stdlib.zipfile as zipfile  # 重写了标准库的zipfile文件，cp437改为gbk，解决zip中文乱码问题
 
@@ -738,7 +740,7 @@ class DataSync:
                 self.get(os.path.join(local_dir, f), os.path.join(remote_dir, f), printf=False)
 
 
-def cache_file(file, make_data_func, *, reset=False, **kwargs):
+def cache_file(file, make_data_func: Callable[[], Any] = None, *, reset=False, **kwargs):
     """ 局部函数功能结果缓存
 
     输入的文件file如果存在则直接读取内容；
@@ -746,14 +748,22 @@ def cache_file(file, make_data_func, *, reset=False, **kwargs):
 
     :param file: 需要缓存的文件路径
     :param make_data_func: 如果文件不存在，则需要生成一份，要提供数据生成函数
+        cache_file可以当装饰器用，此时不用显式指定该参数
     :param reset: 如果file是否已存在，都用make_data_func强制重置一遍
     :param kwargs: 可以传递read、write支持的扩展参数
     :return: 从缓存文件直接读取到的数据
     """
-    file = File(file)
-    if file and not reset:  # 文件存在，直接读取返回
-        data = file.read(**kwargs)
-    else:  # 文件不存在则要生成一份数据
-        data = make_data_func()
-        file.write(data, **kwargs)
-    return data
+
+    def decorator(func):
+        def wrapper(*args2, **kwargs2):
+            f = File(file)
+            if f and not reset:  # 文件存在，直接读取返回
+                data = f.read(**kwargs)
+            else:  # 文件不存在则要生成一份数据
+                data = func(*args2, **kwargs2)
+                f.write(data, **kwargs)
+            return data
+
+        return wrapper
+
+    return decorator(make_data_func)() if make_data_func else decorator
